<div align="center">
  
  [![Package Tests](https://github.com/SG60/sgmusic/actions/workflows/tests.yml/badge.svg)](https://github.com/SG60/sgmusic/actions/workflows/tests.yml)
  [![codecov](https://codecov.io/gh/SG60/sgmusic/branch/master/graph/badge.svg?token=BXYBVS5HF9)](https://codecov.io/gh/SG60/sgmusic)
  [![Code Style](https://github.com/SG60/sgmusic/actions/workflows/code-style.yml/badge.svg)](https://github.com/SG60/sgmusic/actions/workflows/code-style.yml)
  [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

  # sgmusic Python Library

</div>



Using poetry, mypy, isort, black.

Pytest for testing.

[commitizen](https://github.com/commitizen-tools/commitizen) for commit messages and semver (use `cz c` for commits, `cz bump` to update version, `git push --tags` to update tags on Github)
